@@ -9,15 +9,14 @@ import sys
 import time
 import zipfile
 from datetime import datetime, timezone
-from typing import Awaitable, Optional, Union
+from typing import Awaitable
 
 import aiofiles
 import aiofiles.os
 import websockets
-from aiofiles import tempfile  # type: ignore
+from aiofiles import tempfile
 from aiologger.levels import LogLevel
 from aiorun import run
-from arcor2_runtime.package import PROJECT_PATH, read_package_meta, write_package_meta
 from dataclasses_jsonschema import ValidationError
 from websockets.server import WebSocketServerProtocol as WsClient
 
@@ -32,17 +31,18 @@ from arcor2.helpers import port_from_url, run_in_executor
 from arcor2.logging import get_aiologger
 from arcor2_execution_data import EVENTS, URL, events, rpc
 from arcor2_execution_data.common import PackageSummary, ProjectMeta
+from arcor2_runtime.package import PROJECT_PATH, read_package_meta, write_package_meta
 
 logger = get_aiologger("Execution")
 
-PROCESS: Union[asyncio.subprocess.Process, None] = None
+PROCESS: asyncio.subprocess.Process | None = None
 PACKAGE_STATE_EVENT: PackageState = PackageState(PackageState.Data())  # undefined state
-RUNNING_PACKAGE_ID: Optional[str] = None
+RUNNING_PACKAGE_ID: None | str = None
 
 # in case of man. written scripts, this might not be sent
-PACKAGE_INFO_EVENT: Optional[PackageInfo] = None
+PACKAGE_INFO_EVENT: None | PackageInfo = None
 
-TASK: Optional[asyncio.Task] = None
+TASK: None | asyncio.Task = None
 
 CLIENTS: set[WsClient] = set()
 
@@ -200,7 +200,7 @@ async def run_package_cb(req: rpc.RunPackage.Request, ui: WsClient) -> None:
 
     logger.info(f"Starting script: {script_path}")
     PROCESS = await asyncio.create_subprocess_exec(
-        "python3.9",
+        "python3.10",
         *args,
         stdin=asyncio.subprocess.PIPE,
         stdout=asyncio.subprocess.PIPE,
@@ -350,7 +350,7 @@ async def get_summary(path: str) -> PackageSummary:
     raise Arcor2Exception("Invalid package.")
 
 
-async def get_opt_summary(path: str) -> Optional[PackageSummary]:
+async def get_opt_summary(path: str) -> None | PackageSummary:
 
     if not os.path.isfile(os.path.join(path, MAIN_SCRIPT_NAME)):
         logger.warn(f"Package at {path} does not contain main script.")
